Author: abrander
Date: 2009-10-13 00:59:34 +0200 (Tue, 13 Oct 2009)
New Revision: 2705

Added:
   trunk/librawstudio/rs-filter-request.c
   trunk/librawstudio/rs-filter-request.h
Removed:
   trunk/librawstudio/rs-filter-param.c
   trunk/librawstudio/rs-filter-param.h
Modified:
   trunk/librawstudio/Makefile.am
   trunk/librawstudio/rawstudio.h
   trunk/librawstudio/rs-filter.c
   trunk/librawstudio/rs-filter.h
   trunk/plugins/basic-render/basic-render.c
   trunk/plugins/cache/cache.c
   trunk/plugins/crop/crop.c
   trunk/plugins/dcp/dcp.c
   trunk/plugins/demosaic/demosaic.c
   trunk/plugins/denoise/denoise.c
   trunk/plugins/exposure-mask/exposure-mask.c
   trunk/plugins/input-file/input-file.c
   trunk/plugins/input-image16/input-image16.c
   trunk/plugins/lensfun/lensfun.c
   trunk/plugins/meta-tiff/tiff-meta.c
   trunk/plugins/resample/resample.c
   trunk/plugins/rotate/rotate.c
   trunk/src/rs-loupe.c
   trunk/src/rs-preview-widget.c
Log:
Renamed RSFilterParam to RSFilterRequest.

Modified: trunk/librawstudio/Makefile.am
===================================================================
--- trunk/librawstudio/Makefile.am      2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/librawstudio/Makefile.am      2009-10-12 22:59:34 UTC (rev 2705)
@@ -20,7 +20,7 @@
        rs-metadata.h \
        rs-filetypes.h \
        rs-filter.h \
-       rs-filter-param.h \
+       rs-filter-request.h \
        rs-filter-response.h \
        rs-output.h \
        rs-plugin-manager.h \
@@ -54,7 +54,7 @@
        rs-metadata.c rs-metadata.h \
        rs-filetypes.c rs-filetypes.h \
        rs-filter.c rs-filter.h \
-       rs-filter-param.c rs-filter-param.h \
+       rs-filter-request.c rs-filter-request.h \
        rs-filter-response.c rs-filter-response.h \
        rs-output.c rs-output.h \
        rs-plugin-manager.c rs-plugin-manager.h \

Modified: trunk/librawstudio/rawstudio.h
===================================================================
--- trunk/librawstudio/rawstudio.h      2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/librawstudio/rawstudio.h      2009-10-12 22:59:34 UTC (rev 2705)
@@ -40,7 +40,7 @@
 #include "rs-lens-db.h"
 #include "rs-filetypes.h"
 #include "rs-plugin.h"
-#include "rs-filter-param.h"
+#include "rs-filter-request.h"
 #include "rs-filter-response.h"
 #include "rs-filter.h"
 #include "rs-output.h"

Deleted: trunk/librawstudio/rs-filter-param.c
===================================================================
--- trunk/librawstudio/rs-filter-param.c        2009-10-12 21:26:46 UTC (rev 
2704)
+++ trunk/librawstudio/rs-filter-param.c        2009-10-12 22:59:34 UTC (rev 
2705)
@@ -1,145 +0,0 @@
-/*
- * Copyright (C) 2006-2009 Anders Brander <[email protected]> and 
- * Anders Kvist <[email protected]>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
USA.
- */
-
-#include <gtk/gtk.h>
-#include "rs-filter-param.h"
-
-struct _RSFilterParam {
-       GObject parent;
-       gboolean roi_set;
-       GdkRectangle roi;
-       gboolean quick;
-};
-
-G_DEFINE_TYPE(RSFilterParam, rs_filter_param, G_TYPE_OBJECT)
-
-static void
-rs_filter_param_finalize(GObject *object)
-{
-       G_OBJECT_CLASS (rs_filter_param_parent_class)->finalize (object);
-}
-
-static void
-rs_filter_param_class_init(RSFilterParamClass *klass)
-{
-       GObjectClass *object_class = G_OBJECT_CLASS (klass);
-
-       object_class->finalize = rs_filter_param_finalize;
-}
-
-static void
-rs_filter_param_init(RSFilterParam *filter_param)
-{
-       filter_param->roi_set = FALSE;
-       filter_param->quick = FALSE;
-}
-
-/**
- * Instantiate a new RSFilterParam
- * @return A new RSFilterParam with a refcount of 1
- */
-RSFilterParam *
-rs_filter_param_new(void)
-{
-       return g_object_new(RS_TYPE_FILTER_PARAM, NULL);
-}
-
-/**
- * Clone a RSFilterParam
- * @param filter_param A RSFilterParam
- * @return A new RSFilterParam with a refcount of 1 with the same settings as
- *         filter_param
- */
-RSFilterParam *
-rs_filter_param_clone(const RSFilterParam *filter_param)
-{
-       RSFilterParam *new_filter_param = rs_filter_param_new();
-
-       if (RS_IS_FILTER_PARAM(filter_param))
-       {
-               new_filter_param->roi_set = filter_param->roi_set;
-               new_filter_param->roi = filter_param->roi;
-               new_filter_param->quick = filter_param->quick;
-       }
-
-       return new_filter_param;
-}
-
-/**
- * Set a region of interest
- * @param filter_param A RSFilterParam
- * @param roi A GdkRectangle describing the ROI or NULL to disable
- */
-void
-rs_filter_param_set_roi(RSFilterParam *filter_param, GdkRectangle *roi)
-{
-       g_assert(RS_IS_FILTER_PARAM(filter_param));
-
-       filter_param->roi_set = FALSE;
-
-       if (roi)
-       {
-               filter_param->roi_set = TRUE;
-               filter_param->roi = *roi;
-       }
-}
-
-/**
- * Get the region of interest from a RSFilterParam
- * @param filter_param A RSFilterParam
- * @return A GdkRectangle describing the ROI or NULL if none is set, the
- *         GdkRectangle belongs to the filter_param and should not be freed
- */
-GdkRectangle *
-rs_filter_param_get_roi(const RSFilterParam *filter_param)
-{
-       GdkRectangle *ret = NULL;
-
-       if (RS_IS_FILTER_PARAM(filter_param) && filter_param->roi_set)
-               ret = &RS_FILTER_PARAM(filter_param)->roi;
-
-       return ret;
-}
-
-/**
- * Mark a request as "quick" allowing filters to priotize speed over quality
- * @param filter_param A RSFilterParam
- * @param quick TRUE to mark a request as QUICK, FALSE to set normal (default)
- */
-void rs_filter_param_set_quick(RSFilterParam *filter_param, gboolean quick)
-{
-       g_assert(RS_IS_FILTER_PARAM(filter_param));
-
-       filter_param->quick = quick;
-}
-
-/**
- * Get quick status of a RSFilterParam
- * @param filter_param A RSFilterParam
- * @return TRUE if quality should be sacrified for speed, FALSE otherwise
- */
-gboolean rs_filter_param_get_quick(const RSFilterParam *filter_param)
-{
-       gboolean ret = FALSE;
-
-       if (RS_IS_FILTER_PARAM(filter_param))
-               ret = filter_param->quick;
-
-       return ret;
-}

Deleted: trunk/librawstudio/rs-filter-param.h
===================================================================
--- trunk/librawstudio/rs-filter-param.h        2009-10-12 21:26:46 UTC (rev 
2704)
+++ trunk/librawstudio/rs-filter-param.h        2009-10-12 22:59:34 UTC (rev 
2705)
@@ -1,87 +0,0 @@
-/*
- * Copyright (C) 2006-2009 Anders Brander <[email protected]> and 
- * Anders Kvist <[email protected]>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
USA.
- */
-
-#ifndef RS_FILTER_PARAM_H
-#define RS_FILTER_PARAM_H
-
-#include <glib-object.h>
-
-G_BEGIN_DECLS
-
-#define RS_TYPE_FILTER_PARAM rs_filter_param_get_type()
-#define RS_FILTER_PARAM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), 
RS_TYPE_FILTER_PARAM, RSFilterParam))
-#define RS_FILTER_PARAM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), 
RS_TYPE_FILTER_PARAM, RSFilterParamClass))
-#define RS_IS_FILTER_PARAM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), 
RS_TYPE_FILTER_PARAM))
-#define RS_IS_FILTER_PARAM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), 
RS_TYPE_FILTER_PARAM))
-#define RS_FILTER_PARAM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), 
RS_TYPE_FILTER_PARAM, RSFilterParamClass))
-
-typedef struct _RSFilterParam RSFilterParam;
-
-typedef struct {
-       GObjectClass parent_class;
-} RSFilterParamClass;
-
-GType rs_filter_param_get_type(void);
-
-/**
- * Instantiate a new RSFilterParam
- * @return A new RSFilterParam with a refcount of 1
- */
-RSFilterParam *rs_filter_param_new(void);
-
-/**
- * Clone a RSFilterParam
- * @param filter_param A RSFilterParam
- * @return A new RSFilterParam with a refcount of 1 with the same settings as
- *         filter_param
- */
-RSFilterParam *rs_filter_param_clone(const RSFilterParam *filter_param);
-
-/**
- * Set a region of interest
- * @param filter_param A RSFilterParam
- * @param roi A GdkRectangle describing the ROI or NULL to disable
- */
-void rs_filter_param_set_roi(RSFilterParam *filter_param, GdkRectangle *roi);
-
-/**
- * Get the region of interest from a RSFilterParam
- * @param filter_param A RSFilterParam
- * @return A GdkRectangle describing the ROI or NULL if none is set, the
- *         GdkRectangle belongs to the filter_param and should not be freed
- */
-GdkRectangle *rs_filter_param_get_roi(const RSFilterParam *filter_param);
-
-/**
- * Mark a request as "quick" allowing filters to priotize speed over quality
- * @param filter_param A RSFilterParam
- * @param quick TRUE to mark a request as QUICK, FALSE to set normal (default)
- */
-void rs_filter_param_set_quick(RSFilterParam *filter_param, gboolean quick);
-
-/**
- * Get quick status of a RSFilterParam
- * @param filter_param A RSFilterParam
- * @return TRUE if quality should be sacrified for speed, FALSE otherwise
- */
-gboolean rs_filter_param_get_quick(const RSFilterParam *filter_param);
-
-G_END_DECLS
-
-#endif /* RS_FILTER_PARAM_H */

Copied: trunk/librawstudio/rs-filter-request.c (from rev 2703, 
trunk/librawstudio/rs-filter-param.c)
===================================================================
--- trunk/librawstudio/rs-filter-request.c                              (rev 0)
+++ trunk/librawstudio/rs-filter-request.c      2009-10-12 22:59:34 UTC (rev 
2705)
@@ -0,0 +1,145 @@
+/*
+ * Copyright (C) 2006-2009 Anders Brander <[email protected]> and 
+ * Anders Kvist <[email protected]>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
USA.
+ */
+
+#include <gtk/gtk.h>
+#include "rs-filter-request.h"
+
+struct _RSFilterRequest {
+       GObject parent;
+       gboolean roi_set;
+       GdkRectangle roi;
+       gboolean quick;
+};
+
+G_DEFINE_TYPE(RSFilterRequest, rs_filter_request, G_TYPE_OBJECT)
+
+static void
+rs_filter_request_finalize(GObject *object)
+{
+       G_OBJECT_CLASS (rs_filter_request_parent_class)->finalize (object);
+}
+
+static void
+rs_filter_request_class_init(RSFilterRequestClass *klass)
+{
+       GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+       object_class->finalize = rs_filter_request_finalize;
+}
+
+static void
+rs_filter_request_init(RSFilterRequest *filter_request)
+{
+       filter_request->roi_set = FALSE;
+       filter_request->quick = FALSE;
+}
+
+/**
+ * Instantiate a new RSFilterRequest
+ * @return A new RSFilterRequest with a refcount of 1
+ */
+RSFilterRequest *
+rs_filter_request_new(void)
+{
+       return g_object_new(RS_TYPE_FILTER_REQUEST, NULL);
+}
+
+/**
+ * Clone a RSFilterRequest
+ * @param filter_request A RSFilterRequest
+ * @return A new RSFilterRequest with a refcount of 1 with the same settings as
+ *         filter_request
+ */
+RSFilterRequest *
+rs_filter_request_clone(const RSFilterRequest *filter_request)
+{
+       RSFilterRequest *new_filter_request = rs_filter_request_new();
+
+       if (RS_IS_FILTER_REQUEST(filter_request))
+       {
+               new_filter_request->roi_set = filter_request->roi_set;
+               new_filter_request->roi = filter_request->roi;
+               new_filter_request->quick = filter_request->quick;
+       }
+
+       return new_filter_request;
+}
+
+/**
+ * Set a region of interest
+ * @param filter_request A RSFilterRequest
+ * @param roi A GdkRectangle describing the ROI or NULL to disable
+ */
+void
+rs_filter_request_set_roi(RSFilterRequest *filter_request, GdkRectangle *roi)
+{
+       g_assert(RS_IS_FILTER_REQUEST(filter_request));
+
+       filter_request->roi_set = FALSE;
+
+       if (roi)
+       {
+               filter_request->roi_set = TRUE;
+               filter_request->roi = *roi;
+       }
+}
+
+/**
+ * Get the region of interest from a RSFilterRequest
+ * @param filter_request A RSFilterRequest
+ * @return A GdkRectangle describing the ROI or NULL if none is set, the
+ *         GdkRectangle belongs to the filter_request and should not be freed
+ */
+GdkRectangle *
+rs_filter_request_get_roi(const RSFilterRequest *filter_request)
+{
+       GdkRectangle *ret = NULL;
+
+       if (RS_IS_FILTER_REQUEST(filter_request) && filter_request->roi_set)
+               ret = &RS_FILTER_REQUEST(filter_request)->roi;
+
+       return ret;
+}
+
+/**
+ * Mark a request as "quick" allowing filters to priotize speed over quality
+ * @param filter_request A RSFilterRequest
+ * @param quick TRUE to mark a request as QUICK, FALSE to set normal (default)
+ */
+void rs_filter_request_set_quick(RSFilterRequest *filter_request, gboolean 
quick)
+{
+       g_assert(RS_IS_FILTER_REQUEST(filter_request));
+
+       filter_request->quick = quick;
+}
+
+/**
+ * Get quick status of a RSFilterRequest
+ * @param filter_request A RSFilterRequest
+ * @return TRUE if quality should be sacrified for speed, FALSE otherwise
+ */
+gboolean rs_filter_request_get_quick(const RSFilterRequest *filter_request)
+{
+       gboolean ret = FALSE;
+
+       if (RS_IS_FILTER_REQUEST(filter_request))
+               ret = filter_request->quick;
+
+       return ret;
+}


Property changes on: trunk/librawstudio/rs-filter-request.c
___________________________________________________________________
Name: svn:mergeinfo
   + 

Copied: trunk/librawstudio/rs-filter-request.h (from rev 2703, 
trunk/librawstudio/rs-filter-param.h)
===================================================================
--- trunk/librawstudio/rs-filter-request.h                              (rev 0)
+++ trunk/librawstudio/rs-filter-request.h      2009-10-12 22:59:34 UTC (rev 
2705)
@@ -0,0 +1,87 @@
+/*
+ * Copyright (C) 2006-2009 Anders Brander <[email protected]> and 
+ * Anders Kvist <[email protected]>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
USA.
+ */
+
+#ifndef RS_FILTER_REQUEST_H
+#define RS_FILTER_REQUEST_H
+
+#include <glib-object.h>
+
+G_BEGIN_DECLS
+
+#define RS_TYPE_FILTER_REQUEST rs_filter_request_get_type()
+#define RS_FILTER_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), 
RS_TYPE_FILTER_REQUEST, RSFilterRequest))
+#define RS_FILTER_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), 
RS_TYPE_FILTER_REQUEST, RSFilterRequestClass))
+#define RS_IS_FILTER_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), 
RS_TYPE_FILTER_REQUEST))
+#define RS_IS_FILTER_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), 
RS_TYPE_FILTER_REQUEST))
+#define RS_FILTER_REQUEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), 
RS_TYPE_FILTER_REQUEST, RSFilterRequestClass))
+
+typedef struct _RSFilterRequest RSFilterRequest;
+
+typedef struct {
+       GObjectClass parent_class;
+} RSFilterRequestClass;
+
+GType rs_filter_request_get_type(void);
+
+/**
+ * Instantiate a new RSFilterRequest
+ * @return A new RSFilterRequest with a refcount of 1
+ */
+RSFilterRequest *rs_filter_request_new(void);
+
+/**
+ * Clone a RSFilterRequest
+ * @param filter_request A RSFilterRequest
+ * @return A new RSFilterRequest with a refcount of 1 with the same settings as
+ *         filter_request
+ */
+RSFilterRequest *rs_filter_request_clone(const RSFilterRequest 
*filter_request);
+
+/**
+ * Set a region of interest
+ * @param filter_request A RSFilterRequest
+ * @param roi A GdkRectangle describing the ROI or NULL to disable
+ */
+void rs_filter_request_set_roi(RSFilterRequest *filter_request, GdkRectangle 
*roi);
+
+/**
+ * Get the region of interest from a RSFilterRequest
+ * @param filter_request A RSFilterRequest
+ * @return A GdkRectangle describing the ROI or NULL if none is set, the
+ *         GdkRectangle belongs to the filter_request and should not be freed
+ */
+GdkRectangle *rs_filter_request_get_roi(const RSFilterRequest *filter_request);
+
+/**
+ * Mark a request as "quick" allowing filters to priotize speed over quality
+ * @param filter_request A RSFilterRequest
+ * @param quick TRUE to mark a request as QUICK, FALSE to set normal (default)
+ */
+void rs_filter_request_set_quick(RSFilterRequest *filter_request, gboolean 
quick);
+
+/**
+ * Get quick status of a RSFilterRequest
+ * @param filter_request A RSFilterRequest
+ * @return TRUE if quality should be sacrified for speed, FALSE otherwise
+ */
+gboolean rs_filter_request_get_quick(const RSFilterRequest *filter_request);
+
+G_END_DECLS
+
+#endif /* RS_FILTER_REQUEST_H */


Property changes on: trunk/librawstudio/rs-filter-request.h
___________________________________________________________________
Name: svn:mergeinfo
   + 

Modified: trunk/librawstudio/rs-filter.c
===================================================================
--- trunk/plugins/cache/cache.c 2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/plugins/cache/cache.c 2009-10-12 22:59:34 UTC (rev 2705)
@@ -54,8 +54,8 @@
 static void finalize(GObject *object);
 static void get_property (GObject *object, guint property_id, GValue *value, 
GParamSpec *pspec);
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
-static RSFilterResponse *get_image8(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
+static RSFilterResponse *get_image8(RSFilter *filter, const RSFilterRequest 
*request);
 static void flush(RSCache *cache);
 static void previous_changed(RSFilter *filter, RSFilter *parent, 
RSFilterChangedMask mask);
 
@@ -179,14 +179,14 @@
 }
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        RSCache *cache = RS_CACHE(filter);
-       GdkRectangle *roi = rs_filter_param_get_roi(param);
+       GdkRectangle *roi = rs_filter_request_get_roi(request);
 
        if (rs_filter_response_has_image(cache->cached_image)) {
 
-               if (rs_filter_response_get_quick(cache->cached_image) && 
!rs_filter_param_get_quick(param))
+               if (rs_filter_response_get_quick(cache->cached_image) && 
!rs_filter_request_get_quick(request))
                        flush(cache);
 
                if (!rs_filter_response_get_roi(cache->cached_image) && roi)
@@ -204,9 +204,9 @@
        if (!rs_filter_response_has_image(cache->cached_image))
        {
                g_object_unref(cache->cached_image);
-               cache->cached_image = rs_filter_get_image(filter->previous, 
param);
+               cache->cached_image = rs_filter_get_image(filter->previous, 
request);
                rs_filter_response_set_roi(cache->cached_image, roi);
-               if (rs_filter_param_get_quick(param))
+               if (rs_filter_request_get_quick(request))
                        rs_filter_response_set_quick(cache->cached_image);
        }
 
@@ -222,14 +222,14 @@
 
 
 static RSFilterResponse *
-get_image8(RSFilter *filter, const RSFilterParam *param)
+get_image8(RSFilter *filter, const RSFilterRequest *request)
 {
        RSCache *cache = RS_CACHE(filter);
-       GdkRectangle *roi = rs_filter_param_get_roi(param);
+       GdkRectangle *roi = rs_filter_request_get_roi(request);
 
        if (rs_filter_response_has_image8(cache->cached_image)) {
 
-               if (rs_filter_response_get_quick(cache->cached_image) && 
!rs_filter_param_get_quick(param))
+               if (rs_filter_response_get_quick(cache->cached_image) && 
!rs_filter_request_get_quick(request))
                        flush(cache);
 
                if (!rs_filter_response_get_roi(cache->cached_image) && roi)
@@ -247,9 +247,9 @@
        if (!rs_filter_response_has_image8(cache->cached_image))
        {
                g_object_unref(cache->cached_image);
-               cache->cached_image = rs_filter_get_image8(filter->previous, 
param);
+               cache->cached_image = rs_filter_get_image8(filter->previous, 
request);
                rs_filter_response_set_roi(cache->cached_image, roi);
-               if (rs_filter_param_get_quick(param))
+               if (rs_filter_request_get_quick(request))
                        rs_filter_response_set_quick(cache->cached_image);
        }
 

Modified: trunk/plugins/crop/crop.c
===================================================================
--- trunk/plugins/crop/crop.c   2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/plugins/crop/crop.c   2009-10-12 22:59:34 UTC (rev 2705)
@@ -63,7 +63,7 @@
 static void get_property (GObject *object, guint property_id, GValue *value, 
GParamSpec *pspec);
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
 static void calc(RSCrop *crop);
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
 static gint get_width(RSFilter *filter);
 static gint get_height(RSFilter *filter);
 
@@ -250,7 +250,7 @@
 }
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        g_assert(RS_IS_FILTER(filter));
        RSCrop *crop = RS_CROP(filter);
@@ -264,7 +264,7 @@
 
        calc(crop);
 
-       previous_response = rs_filter_get_image(filter->previous, param);
+       previous_response = rs_filter_get_image(filter->previous, request);
        /* Special case for full crop */
        if ((crop->width == parent_width) && (crop->height==parent_height))
                return previous_response;

Modified: trunk/plugins/dcp/dcp.c
===================================================================
--- trunk/plugins/dcp/dcp.c     2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/plugins/dcp/dcp.c     2009-10-12 22:59:34 UTC (rev 2705)
@@ -101,7 +101,7 @@
 
 static void get_property (GObject *object, guint property_id, GValue *value, 
GParamSpec *pspec);
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
 static void settings_changed(RSSettings *settings, RSSettingsMask mask, RSDcp 
*dcp);
 static RS_xy_COORD neutral_to_xy(RSDcp *dcp, const RS_VECTOR3 *neutral);
 static RS_MATRIX3 find_xyz_to_camera(RSDcp *dcp, const RS_xy_COORD *white_xy, 
RS_MATRIX3 *forward_matrix);
@@ -322,7 +322,7 @@
 }
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        RSDcp *dcp = RS_DCP(filter);
        GdkRectangle *roi;
@@ -332,7 +332,7 @@
        RS_IMAGE16 *output;
        RS_IMAGE16 *tmp;
 
-       previous_response = rs_filter_get_image(filter->previous, param);
+       previous_response = rs_filter_get_image(filter->previous, request);
 
        if (!RS_IS_FILTER(filter->previous))
                return previous_response;
@@ -348,7 +348,7 @@
        rs_filter_response_set_image(response, output);
        g_object_unref(output);
 
-       if ((roi = rs_filter_param_get_roi(param)))
+       if ((roi = rs_filter_request_get_roi(request)))
                tmp = rs_image16_new_subframe(output, roi);
        else
                tmp = g_object_ref(output);

Modified: trunk/plugins/demosaic/demosaic.c
===================================================================
--- trunk/plugins/demosaic/demosaic.c   2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/plugins/demosaic/demosaic.c   2009-10-12 22:59:34 UTC (rev 2705)
@@ -71,7 +71,7 @@
 
 static void get_property (GObject *object, guint property_id, GValue *value, 
GParamSpec *pspec);
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
 static inline int fc_INDI (const unsigned int filters, const int row, const 
int col);
 static void border_interpolate_INDI (const ThreadInfo* t, int colors, int 
border);
 static void lin_interpolate_INDI(RS_IMAGE16 *image, RS_IMAGE16 *output, const 
unsigned int filters, const int colors);
@@ -163,7 +163,7 @@
   (int)(filters >> ((((row) << 1 & 14) + ((col) & 1)) << 1) & 3)
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        RSDemosaic *demosaic = RS_DEMOSAIC(filter);
        RSFilterResponse *previous_response;
@@ -173,7 +173,7 @@
        guint filters;
        RS_DEMOSAIC method;
 
-       previous_response = rs_filter_get_image(filter->previous, param);
+       previous_response = rs_filter_get_image(filter->previous, request);
 
        input = rs_filter_response_get_image(previous_response);
 
@@ -197,7 +197,7 @@
        g_object_unref(output);
 
        method = demosaic->method;
-       if (rs_filter_param_get_quick(param))
+       if (rs_filter_request_get_quick(request))
        {
                method = RS_DEMOSAIC_NONE;
                rs_filter_response_set_quick(response);

Modified: trunk/plugins/denoise/denoise.c
===================================================================
--- trunk/plugins/denoise/denoise.c     2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/plugins/denoise/denoise.c     2009-10-12 22:59:34 UTC (rev 2705)
@@ -58,7 +58,7 @@
 
 static void get_property (GObject *object, guint property_id, GValue *value, 
GParamSpec *pspec);
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
 static void settings_changed(RSSettings *settings, RSSettingsMask mask, 
RSDenoise *denoise);
 
 static RSFilterClass *rs_denoise_parent_class = NULL;
@@ -223,7 +223,7 @@
 }
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        RSDenoise *denoise = RS_DENOISE(filter);
        GdkRectangle *roi;
@@ -233,7 +233,7 @@
        RS_IMAGE16 *output;
        RS_IMAGE16 *tmp;
 
-       previous_response = rs_filter_get_image(filter->previous, param);
+       previous_response = rs_filter_get_image(filter->previous, request);
 
        if (!RS_IS_FILTER(filter->previous))
                return previous_response;
@@ -246,7 +246,7 @@
        g_object_unref(previous_response);
 
        /* If the request is marked as "quick", bail out, we're slow */
-       if (rs_filter_param_get_quick(param))
+       if (rs_filter_request_get_quick(request))
        {
                rs_filter_response_set_image(response, input);
                rs_filter_response_set_quick(response);
@@ -260,7 +260,7 @@
        rs_filter_response_set_image(response, output);
        g_object_unref(output);
 
-       if ((roi = rs_filter_param_get_roi(param)))
+       if ((roi = rs_filter_request_get_roi(request)))
                tmp = rs_image16_new_subframe(output, roi);
        else
                tmp = g_object_ref(output);

Modified: trunk/plugins/exposure-mask/exposure-mask.c
===================================================================
--- trunk/plugins/exposure-mask/exposure-mask.c 2009-10-12 21:26:46 UTC (rev 
2704)
+++ trunk/plugins/exposure-mask/exposure-mask.c 2009-10-12 22:59:34 UTC (rev 
2705)
@@ -48,7 +48,7 @@
 
 static void get_property (GObject *object, guint property_id, GValue *value, 
GParamSpec *pspec);
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
-static RSFilterResponse *get_image8(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image8(RSFilter *filter, const RSFilterRequest 
*request);
 
 static RSFilterClass *rs_exposure_mask_parent_class = NULL;
 
@@ -116,7 +116,7 @@
 }
 
 static RSFilterResponse *
-get_image8(RSFilter *filter, const RSFilterParam *param)
+get_image8(RSFilter *filter, const RSFilterRequest *request)
 {
        RSExposureMask *exposure_mask = RS_EXPOSURE_MASK(filter);
        RSFilterResponse *previous_response;
@@ -129,7 +129,7 @@
        guchar *out_pixel;
        gint channels;
 
-       previous_response = rs_filter_get_image8(filter->previous, param);
+       previous_response = rs_filter_get_image8(filter->previous, request);
        input = rs_filter_response_get_image8(previous_response);
        response = rs_filter_response_clone(previous_response);
        g_object_unref(previous_response);

Modified: trunk/plugins/input-file/input-file.c
===================================================================
--- trunk/plugins/input-file/input-file.c       2009-10-12 21:26:46 UTC (rev 
2704)
+++ trunk/plugins/input-file/input-file.c       2009-10-12 22:59:34 UTC (rev 
2705)
@@ -47,7 +47,7 @@
 
 static void get_property (GObject *object, guint property_id, GValue *value, 
GParamSpec *pspec);
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
 static gint get_width(RSFilter *filter);
 static gint get_height(RSFilter *filter);
 
@@ -125,7 +125,7 @@
 }
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        RSFilterResponse *response = rs_filter_response_new();
        RSInputFile *input = RS_INPUT_FILE(filter);

Modified: trunk/plugins/input-image16/input-image16.c
===================================================================
--- trunk/plugins/input-image16/input-image16.c 2009-10-12 21:26:46 UTC (rev 
2704)
+++ trunk/plugins/input-image16/input-image16.c 2009-10-12 22:59:34 UTC (rev 
2705)
@@ -53,7 +53,7 @@
 
 static void get_property (GObject *object, guint property_id, GValue *value, 
GParamSpec *pspec);
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
 static RSIccProfile *get_icc_profile(RSFilter *filter);
 static void dispose (GObject *object);
 static gint get_width(RSFilter *filter);
@@ -176,7 +176,7 @@
 }
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        RSFilterResponse *response = rs_filter_response_new();
        RSInputImage16 *input_image16 = RS_INPUT_IMAGE16(filter);

Modified: trunk/plugins/lensfun/lensfun.c
===================================================================
--- trunk/plugins/lensfun/lensfun.c     2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/plugins/lensfun/lensfun.c     2009-10-12 22:59:34 UTC (rev 2705)
@@ -61,7 +61,7 @@
 
 static void get_property (GObject *object, guint property_id, GValue *value, 
GParamSpec *pspec);
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
 static void inline rs_image16_nearest_full(RS_IMAGE16 *in, gushort *out, 
gfloat *pos);
 static void inline rs_image16_bilinear_full(RS_IMAGE16 *in, gushort *out, 
gfloat *pos);
 
@@ -239,7 +239,7 @@
 
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        RSLensfun *lensfun = RS_LENSFUN(filter);
        RSFilterResponse *previous_response;
@@ -249,12 +249,12 @@
        const gchar *make = NULL;
        const gchar *model = NULL;
 
-       previous_response = rs_filter_get_image(filter->previous, param);
+       previous_response = rs_filter_get_image(filter->previous, request);
        input = rs_filter_response_get_image(previous_response);
        response = rs_filter_response_clone(previous_response);
        g_object_unref(previous_response);
 
-       if (rs_filter_param_get_quick(param))
+       if (rs_filter_request_get_quick(request))
        {
                rs_filter_response_set_quick(response);
                if (input)

Modified: trunk/plugins/meta-tiff/tiff-meta.c
===================================================================
--- trunk/plugins/meta-tiff/tiff-meta.c 2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/plugins/meta-tiff/tiff-meta.c 2009-10-12 22:59:34 UTC (rev 2705)
@@ -1430,13 +1430,13 @@
 
        RSFilter *finput = rs_filter_new("RSInputFile", NULL);
        RSFilter *fdemosaic = rs_filter_new("RSDemosaic", finput);
-       RSFilterParam *param = rs_filter_param_new();
+       RSFilterRequest *request = rs_filter_request_new();
 
        g_object_set(finput, "filename", service, NULL);
-       rs_filter_param_set_roi(param, FALSE);
-       rs_filter_param_set_quick(param, TRUE);
+       rs_filter_request_set_roi(request, FALSE);
+       rs_filter_request_set_quick(request, TRUE);
 
-       RSFilterResponse *response = rs_filter_get_image(fdemosaic, param);
+       RSFilterResponse *response = rs_filter_get_image(fdemosaic, request);
 
        if (rs_filter_response_has_image(response))
        {
@@ -1447,21 +1447,21 @@
                image_raw = rs_filter_response_get_image(response);
 
                /* Scale down for higher speed */
-               g_object_unref(param);
+               g_object_unref(request);
                g_object_unref(finput);
                g_object_unref(response);
-               param = rs_filter_param_new();
+               request = rs_filter_request_new();
                finput = rs_filter_new("RSInputImage16", NULL);
                RSFilter *fresample = rs_filter_new("RSResample", finput);
 
                g_object_set(finput, "image", image_raw, "filename", service, 
NULL);
-               rs_filter_param_set_roi(param, FALSE);
-               rs_filter_param_set_quick(param, TRUE);
+               rs_filter_request_set_roi(request, FALSE);
+               rs_filter_request_set_quick(request, TRUE);
                g_object_set(fresample, "width", image_raw->w/8,
                             "height", image_raw->h/8, NULL);
 
                /* Request the scaled image */
-               response = rs_filter_get_image(fresample, param);
+               response = rs_filter_get_image(fresample, request);
                image_raw_scaled = rs_filter_response_get_image(response);
 
                /* Transform image */
@@ -1486,7 +1486,7 @@
                g_object_unref(rct);
        }
 
-       g_object_unref(param);
+       g_object_unref(request);
        g_object_unref(response);
        g_object_unref(finput);
        g_object_unref(fdemosaic);

Modified: trunk/plugins/resample/resample.c
===================================================================
--- trunk/plugins/resample/resample.c   2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/plugins/resample/resample.c   2009-10-12 22:59:34 UTC (rev 2705)
@@ -77,7 +77,7 @@
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
 static void previous_changed(RSFilter *filter, RSFilter *parent, 
RSFilterChangedMask mask);
 static RSFilterChangedMask recalculate_dimensions(RSResample *resample);
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
 static gint get_width(RSFilter *filter);
 static gint get_height(RSFilter *filter);
 static void ResizeH(ResampleInfo *info);
@@ -277,7 +277,7 @@
 }
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        gboolean use_fast = FALSE;
        RSResample *resample = RS_RESAMPLE(filter);
@@ -290,15 +290,15 @@
        gint input_height = rs_filter_get_height(filter->previous);
 
        /* Remove ROI, it doesn't make sense across resampler */
-       if (rs_filter_param_get_roi(param))
+       if (rs_filter_request_get_roi(request))
        {
-               RSFilterParam *new_param = rs_filter_param_clone(param);
-               rs_filter_param_set_roi(new_param, NULL);
-               previous_response = rs_filter_get_image(filter->previous, 
new_param);
-               g_object_unref(new_param);
+               RSFilterRequest *new_request = rs_filter_request_clone(request);
+               rs_filter_request_set_roi(new_request, NULL);
+               previous_response = rs_filter_get_image(filter->previous, 
new_request);
+               g_object_unref(new_request);
        }
        else
-               previous_response = rs_filter_get_image(filter->previous, 
param);
+               previous_response = rs_filter_get_image(filter->previous, 
request);
 
        /* Return the input, if the new size is uninitialized */
        if ((resample->new_width == -1) || (resample->new_height == -1))
@@ -319,7 +319,7 @@
        /* Use compatible (and slow) version if input isn't 3 channels and 
pixelsize 4 */
        gboolean use_compatible = ( ! ( input->pixelsize == 4 && 
input->channels == 3));
 
-       if (rs_filter_param_get_quick(param))
+       if (rs_filter_request_get_quick(request))
        {
                use_fast = TRUE;
                rs_filter_response_set_quick(response);

Modified: trunk/plugins/rotate/rotate.c
===================================================================
--- trunk/plugins/rotate/rotate.c       2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/plugins/rotate/rotate.c       2009-10-12 22:59:34 UTC (rev 2705)
@@ -70,7 +70,7 @@
 static void get_property (GObject *object, guint property_id, GValue *value, 
GParamSpec *pspec);
 static void set_property (GObject *object, guint property_id, const GValue 
*value, GParamSpec *pspec);
 static void previous_changed(RSFilter *filter, RSFilter *parent, 
RSFilterChangedMask mask);
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
 static void turn_right_angle(RS_IMAGE16 *in, RS_IMAGE16 *out, gint start_y, 
gint end_y, const int direction);
 static gint get_width(RSFilter *filter);
 static gint get_height(RSFilter *filter);
@@ -188,7 +188,7 @@
 }
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        RSRotate *rotate = RS_ROTATE(filter);
        RSFilterResponse *previous_response;
@@ -197,7 +197,7 @@
        RS_IMAGE16 *output = NULL;
        gboolean use_fast = FALSE;
 
-       previous_response = rs_filter_get_image(filter->previous, param);
+       previous_response = rs_filter_get_image(filter->previous, request);
 
        if ((rotate->angle < 0.001) && (rotate->orientation==0))
                return previous_response;
@@ -224,7 +224,7 @@
                recalculate(rotate);
        }
 
-       if (rs_filter_param_get_quick(param))
+       if (rs_filter_request_get_quick(request))
        {
                use_fast = TRUE;
                rs_filter_response_set_quick(response);

Modified: trunk/src/rs-loupe.c
===================================================================
--- trunk/src/rs-loupe.c        2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/src/rs-loupe.c        2009-10-12 22:59:34 UTC (rev 2705)
@@ -232,23 +232,23 @@
        gtk_window_get_size(GTK_WINDOW(loupe), &window_width, &window_height);
 
        /* Create request ROI */
-       RSFilterParam *param = rs_filter_param_new();
-       GdkRectangle request;
-       request.x = CLAMP(loupe->center_x - window_width/2, 0, 
width-window_width-1);
-       request.y = CLAMP(loupe->center_y - window_height/2, 0, 
height-window_height-1);
-       request.width = window_width;
-       request.height = window_height;
-       rs_filter_param_set_roi(param, &request);
+       RSFilterRequest *request = rs_filter_request_new();
+       GdkRectangle roi;
+       roi.x = CLAMP(loupe->center_x - window_width/2, 0, 
width-window_width-1);
+       roi.y = CLAMP(loupe->center_y - window_height/2, 0, 
height-window_height-1);
+       roi.width = window_width;
+       roi.height = window_height;
+       rs_filter_request_set_roi(request, &roi);
 
-       RSFilterResponse *response = rs_filter_get_image8(loupe->filter, param);
+       RSFilterResponse *response = rs_filter_get_image8(loupe->filter, 
request);
        GdkPixbuf *buffer = rs_filter_response_get_image8(response);
        g_object_unref(response);
 
-       g_object_unref(param);
+       g_object_unref(request);
 
-       add_border(loupe, buffer, &request);
+       add_border(loupe, buffer, &roi);
 
-       gdk_draw_pixbuf(drawable, gc, buffer, request.x, request.y, 0, 0, 
request.width, request.height, GDK_RGB_DITHER_NONE, 0, 0);
+       gdk_draw_pixbuf(drawable, gc, buffer, roi.x, roi.y, 0, 0, roi.width, 
roi.height, GDK_RGB_DITHER_NONE, 0, 0);
 
        g_object_unref(buffer);
        g_object_unref(gc);

Modified: trunk/src/rs-preview-widget.c
===================================================================
--- trunk/src/rs-preview-widget.c       2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/src/rs-preview-widget.c       2009-10-12 22:59:34 UTC (rev 2705)
@@ -152,7 +152,7 @@
        RSFilter *filter_cache3[MAX_VIEWS];
        RSFilter *filter_end[MAX_VIEWS]; /* For convenience */
 
-       RSFilterParam *param[MAX_VIEWS];
+       RSFilterRequest *request[MAX_VIEWS];
        GdkRectangle *last_roi[MAX_VIEWS];
        RS_PHOTO *photo;
        void *transform;
@@ -345,7 +345,7 @@
                g_object_set(preview->filter_resample[i], "bounding-box", TRUE, 
NULL);
                g_object_set(preview->filter_cache3[i], "latency", 1, NULL);
 
-               preview->param[i] = rs_filter_param_new();
+               preview->request[i] = rs_filter_request_new();
 #if MAX_VIEWS > 3
 #error Fix line below
 #endif
@@ -584,7 +584,7 @@
 
                for(view=0;view<MAX_VIEWS;view++) 
                {
-                       rs_filter_param_set_quick(preview->param[view], TRUE);
+                       rs_filter_request_set_quick(preview->request[view], 
TRUE);
                        g_object_set(preview->filter_render[view], "settings", 
preview->photo->settings[preview->snapshot[view]], NULL);
                        g_object_set(preview->filter_denoise[view], "settings", 
preview->photo->settings[preview->snapshot[view]], NULL);
                }
@@ -902,7 +902,7 @@
                return;
 
        /* FIXME: Check all views.*/
-       if (rs_filter_param_get_quick(preview->param[0]) && 
!preview->keep_quick_enabled)
+       if (rs_filter_request_get_quick(preview->request[0]) && 
!preview->keep_quick_enabled)
                full_redraw = TRUE;
 
        if (full_redraw)
@@ -1117,7 +1117,7 @@
        preview->keep_quick_enabled = keep_quick;
 
        for(i=0;i<MAX_VIEWS;i++)
-               rs_filter_param_set_quick(preview->param[i], TRUE);
+               rs_filter_request_set_quick(preview->request[i], TRUE);
 
 }
 
@@ -1373,12 +1373,12 @@
                                preview->last_roi[i] = g_new(GdkRectangle, 1);
                        *preview->last_roi[i] = roi;
 
-                       rs_filter_param_set_roi(preview->param[i], &roi);
+                       rs_filter_request_set_roi(preview->request[i], &roi);
 
                        /* Clone, now so it cannot change while filters are 
being called */
-                       RSFilterParam *new_param = 
rs_filter_param_clone(preview->param[i]);  
+                       RSFilterRequest *new_request = 
rs_filter_request_clone(preview->request[i]);  
 
-                       RSFilterResponse *response = 
rs_filter_get_image8(preview->filter_end[i], new_param);
+                       RSFilterResponse *response = 
rs_filter_get_image8(preview->filter_end[i], new_request);
                        GdkPixbuf *buffer = 
rs_filter_response_get_image8(response);
 
                        if (buffer)
@@ -1396,12 +1396,12 @@
                                g_object_unref(buffer);
                        }
 
-                       if(rs_filter_param_get_quick(new_param) && 
!preview->keep_quick_enabled)
+                       if(rs_filter_request_get_quick(new_request) && 
!preview->keep_quick_enabled)
                        {
-                               rs_filter_param_set_quick(preview->param[i], 
FALSE);
+                               
rs_filter_request_set_quick(preview->request[i], FALSE);
                                gdk_window_invalidate_rect(window, &area, 
FALSE);
                        }
-                       g_object_unref(new_param);
+                       g_object_unref(new_request);
                        g_object_unref(response);
                }
 
@@ -2432,11 +2432,11 @@
        if (!preview->last_roi[view])
                return FALSE;
 
-       RSFilterResponse *response = 
rs_filter_get_image(preview->filter_cache1[view], preview->param[view]);
+       RSFilterResponse *response = 
rs_filter_get_image(preview->filter_cache1[view], preview->request[view]);
        RS_IMAGE16 *image = rs_filter_response_get_image(response);
        g_object_unref(response);
 
-       response = rs_filter_get_image8(preview->filter_end[view], 
preview->param[view]);
+       response = rs_filter_get_image8(preview->filter_end[view], 
preview->request[view]);
        GdkPixbuf *buffer = rs_filter_response_get_image8(response);
        g_object_unref(response);
 


_______________________________________________
Rawstudio-commit mailing list
[email protected]
http://rawstudio.org/cgi-bin/mailman/listinfo/rawstudio-commit

Reply via email to
--- trunk/librawstudio/rs-filter.c      2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/librawstudio/rs-filter.c      2009-10-12 22:59:34 UTC (rev 2705)
@@ -173,11 +173,11 @@
 /**
  * Get the output image from a RSFilter
  * @param filter A RSFilter
  * @param param A RSFilterParam defining parameters for a image request
  * @return A RS_IMAGE16, this must be unref'ed
  */
 RSFilterResponse *
-rs_filter_get_image(RSFilter *filter, const RSFilterParam *param)
+rs_filter_get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        filter_debug("rs_filter_get_image(%s [%p])", RS_FILTER_NAME(filter), 
filter);
 
@@ -196,9 +196,9 @@
        count++;
 
        if (RS_FILTER_GET_CLASS(filter)->get_image && filter->enabled)
-               response = RS_FILTER_GET_CLASS(filter)->get_image(filter, 
param);
+               response = RS_FILTER_GET_CLASS(filter)->get_image(filter, 
request);
        else
-               response = rs_filter_get_image(filter->previous, param);
+               response = rs_filter_get_image(filter->previous, request);
 
        g_assert(RS_IS_FILTER_RESPONSE(response));
 
@@ -234,11 +234,11 @@
 /**
  * Get 8 bit output image from a RSFilter
  * @param filter A RSFilter
  * @param param A RSFilterParam defining parameters for a image request
  * @return A RS_IMAGE16, this must be unref'ed
  */
 RSFilterResponse *
-rs_filter_get_image8(RSFilter *filter, const RSFilterParam *param)
+rs_filter_get_image8(RSFilter *filter, const RSFilterRequest *request)
 {
        filter_debug("rs_filter_get_image8(%s [%p])", RS_FILTER_NAME(filter), 
filter);
 
@@ -257,9 +257,9 @@
        count++;
 
        if (RS_FILTER_GET_CLASS(filter)->get_image8 && filter->enabled)
-               response = RS_FILTER_GET_CLASS(filter)->get_image8(filter, 
param);
+               response = RS_FILTER_GET_CLASS(filter)->get_image8(filter, 
request);
        else if (filter->previous)
-               response = rs_filter_get_image8(filter->previous, param);
+               response = rs_filter_get_image8(filter->previous, request);
 
        g_assert(RS_IS_FILTER_RESPONSE(response));
 
@@ -173,11 +173,11 @@
  * Get the output image from a RSFilter
  * @param filter A RSFilter
- * @param param A RSFilterParam defining parameters for a image request
+ * @param param A RSFilterRequest defining parameters for a image request
  * @return A RS_IMAGE16, this must be unref'ed
  */
@@ -234,11 +234,11 @@
  * Get 8 bit output image from a RSFilter
  * @param filter A RSFilter
- * @param param A RSFilterParam defining parameters for a image request
+ * @param param A RSFilterRequest defining parameters for a image request
  * @return A RS_IMAGE16, this must be unref'ed
  */

Modified: trunk/librawstudio/rs-filter.h
===================================================================
--- trunk/librawstudio/rs-filter.h      2009-10-12 21:26:46 UTC (rev 2704)
+++ trunk/librawstudio/rs-filter.h      2009-10-12 22:59:34 UTC (rev 2705)
@@ -79,7 +79,7 @@
 typedef struct _RSFilter RSFilter;
 typedef struct _RSFilterClass RSFilterClass;
 
-typedef RSFilterResponse *(*RSFilterFunc)(RSFilter *filter, const 
RSFilterParam *param);
+typedef RSFilterResponse *(*RSFilterFunc)(RSFilter *filter, const 
RSFilterRequest *request);
 
 struct _RSFilter {
        GObject parent;
@@ -131,18 +131,18 @@
 /**
  * Get the output image from a RSFilter
  * @param filter A RSFilter
  * @param param A RSFilterParam defining parameters for a image request
  * @return A RS_IMAGE16, this must be unref'ed
  */
-extern RSFilterResponse *rs_filter_get_image(RSFilter *filter, const 
RSFilterParam *param);
+extern RSFilterResponse *rs_filter_get_image(RSFilter *filter, const 
RSFilterRequest *request);
 
 /**
  * Get 8 bit output image from a RSFilter
  * @param filter A RSFilter
  * @param param A RSFilterParam defining parameters for a image request
  * @return A RS_IMAGE16, this must be unref'ed
  */
-extern RSFilterResponse *rs_filter_get_image8(RSFilter *filter, const 
RSFilterParam *param);
+extern RSFilterResponse *rs_filter_get_image8(RSFilter *filter, const 
RSFilterRequest *request);
 
 /**
  * Get the ICC profile from a filter

Modified: trunk/plugins/basic-render/basic-render.c
===================================================================
--- trunk/plugins/basic-render/basic-render.c   2009-10-12 21:26:46 UTC (rev 
2704)
+++ trunk/plugins/basic-render/basic-render.c   2009-10-12 22:59:34 UTC (rev 
2705)
@@ -125,8 +125,8 @@
 static gpointer thread_func_sse8(gpointer _thread_info);
 static gpointer thread_func_sse8_cms(gpointer _thread_info);
 #endif /* __i386__ || __x86_64__ */
-static RSFilterResponse *get_image(RSFilter *filter, const RSFilterParam 
*param);
-static RSFilterResponse *get_image8(RSFilter *filter, const RSFilterParam 
*param);
+static RSFilterResponse *get_image(RSFilter *filter, const RSFilterRequest 
*request);
+static RSFilterResponse *get_image8(RSFilter *filter, const RSFilterRequest 
*request);
 static RSIccProfile *get_icc_profile(RSFilter *filter);
 
 static RSFilterClass *rs_basic_render_parent_class = NULL;
@@ -957,7 +957,7 @@
 #endif /* __i386__ || __x86_64__ */
 
 static RSFilterResponse *
-get_image(RSFilter *filter, const RSFilterParam *param)
+get_image(RSFilter *filter, const RSFilterRequest *request)
 {
        RSBasicRenderClass *klass = RS_BASIC_RENDER_GET_CLASS(filter);
        guint i, y_offset, y_per_thread, threaded_h;
@@ -968,7 +968,7 @@
        RS_IMAGE16 *input;
        RS_IMAGE16 *output = NULL;
 
-       previous_response = rs_filter_get_image(filter->previous, param);
+       previous_response = rs_filter_get_image(filter->previous, request);
        input = rs_filter_response_get_image(previous_response);
        if (!RS_IS_IMAGE16(input))
                return previous_response;
@@ -1018,7 +1018,7 @@
 }
 
 static RSFilterResponse *
-get_image8(RSFilter *filter, const RSFilterParam *param)
+get_image8(RSFilter *filter, const RSFilterRequest *request)
 {
        RSBasicRenderClass *klass = RS_BASIC_RENDER_GET_CLASS(filter);
        guint i, x_offset, y_offset, y_per_thread, threaded_h;
@@ -1031,7 +1031,7 @@
        gint width, height;
        GdkRectangle *roi;
 
-       previous_response = rs_filter_get_image(filter->previous, param);
+       previous_response = rs_filter_get_image(filter->previous, request);
        input = rs_filter_response_get_image(previous_response);
        if (!RS_IS_IMAGE16(input))
                return previous_response;
@@ -1046,7 +1046,7 @@
        render_matrix(basic_render);
        prepare_lcms(basic_render);
 
-       if ((roi = rs_filter_param_get_roi(param)))
+       if ((roi = rs_filter_request_get_roi(request)))
        {
                width = MIN(roi->width, input->w);
                height = MIN(roi->height, input->h);
@@ -131,18 +131,18 @@
  * Get the output image from a RSFilter
  * @param filter A RSFilter
- * @param param A RSFilterParam defining parameters for a image request
+ * @param param A RSFilterRequest defining parameters for a image request
  * @return A RS_IMAGE16, this must be unref'ed
  */
@@ -131,18 +131,18 @@
  * Get 8 bit output image from a RSFilter
  * @param filter A RSFilter
- * @param param A RSFilterParam defining parameters for a image request
+ * @param param A RSFilterRequest defining parameters for a image request
  * @return A RS_IMAGE16, this must be unref'ed
  */

Modified: trunk/plugins/cache/cache.c
===================================================================